Other Writing — Django-Vitae 0.0.1 documentation

# Other Writing

Django-Vitae comes with a model to describe writing other than presenting research findings. These can be book reviews, op eds, blog posts, or other types of non-academic writing. The `OtherWriting` class stores instances of these writings.

The `OtherWriting` model has five required fields:

- `title`
- `short_title`
- `slug`
- `date`
- `venue` (e.g., publication where the writing was published)

The `OtherWriting` includes a field `type` that you may use to group different types of writing together on a CV (Django-Vitae does not, however, currently do this by default).

A full reference of fields included in the `OtherWriting` model can be found in the `cv.models.OtherWriting` model reference.